function [ prelIntArray ] = preliminary_segment(data, attributes, attName, t_wind, t_overlap, eta_p)
%This funcation performs Larsson's preliminary segmentation
%   @data to use
%   @attributes describing the data
%   @attName attribute name to consider
%
%   @t_wind is window size in ms, default is 22
%   @t_overlap is overlp size in ms, default is 6
%   @eta_p - threshold for average p-value of Reyleigh test for each sample,
%   default value (from paper) is 0.01
%   
%   @prelIntArray preliminary segmentation of attName intervals

if nargin < 3
    error('At least 3 arguments are needed');
end
if nargin < 4
    t_wind = 22000; % us
end
if nargin < 5
    t_overlap = 6000; % us
end 
if nargin < 6
    eta_p = 0.01;
end
% add search path for circ_rtest
addpath('CircStat2012/');

% get position of attributes in data
timeIndex = GetAttPositionArff(attributes, 'time');
xIndex = GetAttPositionArff(attributes, 'x');
yIndex = GetAttPositionArff(attributes, 'y');
attIndex = GetAttPositionArff(attributes, attName);

moveId = 0; % unassigned
intArray = GetIntervalsIndexArff(data, attributes, attName, moveId);

% calculate angle
angle = zeros(1, size(data,1));
for i=1:size(intArray,1)
    startIndex = intArray(i,1);
    endIndex = intArray(i,2);

    for j=startIndex:endIndex-1
        angle(j) = atan2(data(j+1,yIndex)-data(j,yIndex), data(j+1,xIndex)-data(j,xIndex));
    end
    % assing same value to the last entry as the penultimate
    if (endIndex-startIndex > 1)
        angle(endIndex) = angle(endIndex-1);
    end
end

% calculate P mean
Pmean = zeros(1, size(data,1));
N = zeros(1, size(data,1));

for i=1:size(intArray,1)
    startIndex = intArray(i,1);
    endIndex = intArray(i,2);

    j=startIndex;
    startInterval = startIndex;
    newStartInterval = startIndex;
    while (j<=endIndex)
        if (data(j,timeIndex) > data(startInterval,timeIndex) + t_overlap)
            newStartInterval = j;
        end

        if (data(j,timeIndex) < data(startInterval,timeIndex) + t_wind)
            j = j + 1; % just move to next
        else
            % get r for all values
            [p z] = circ_rtest(angle(startInterval:j-1));
            Pmean(startInterval:j-1) = Pmean(startInterval:j-1) + p;
            N(startInterval:j-1) = N(startInterval:j-1) + 1;
            startInterval = newStartInterval;
            j = newStartInterval;
        end
    end

    % get last entries of intersaccadic interval
    [p z] = circ_rtest(angle(startInterval:endIndex)');
    Pmean(startInterval:j-1) = Pmean(startInterval:endIndex) + p;
    N(startInterval:j-1) = N(startInterval:endIndex) + 1;

end

Pmean = Pmean./N;

% convert Pmean to 0 1 array
Pmean(Pmean(:) < eta_p) = 0;
Pmean(Pmean(:) ~= 0) = 1;

prelIntArray = zeros(0,2);

for i=1:size(intArray,1)
    startIndex = intArray(i,1);
    endIndex = intArray(i,2);

    intStart = startIndex;
    for j=startIndex+1:endIndex
        if (Pmean(j) ~= Pmean(j-1))
            prelIntArray = [prelIntArray; intStart j-1];
            intStart = j;
        end
    end

    % add last part of interval
    if (intStart ~= endIndex)
        prelIntArray = [prelIntArray; intStart endIndex];
    end
end
end
