% function LoadCoordAndConfArff:
% loads an arff file and returns data if time,x,y,confidence attributes are present
% Converts confidence from 0,4 to 1,0
%
% input:
%   arffFile    - arff file to read
%
% output:
%   data        - nx3 array (time,x,y)
%   pixelX      - pixels in x direction
%   pixelY      - pixels in y direction
%   width_m     - width of monitor in meters
%   height_m    - height of monito in meters
%   distance_m  - distance from monitor in meters
%   conf        - confidence of returned data. Values of 0 and 1 for compatibility with .coord convention

function [data, pixelX, pixelY, width_m, height_m, distance_m, conf] = LoadCoordAndConfArff(arffFile)
    % initialize data
    data = zeros(0,3);
    pixelX = -1;
    pixelY = -1;
    width = -1;
    height = -1;
    distance = -1;
    conf = [];

    % load data from arff file
    [arffData, metadata, attributes, relation] = LoadArff(arffFile);

    % find index of time, x, y confindence in attributes
    timeIndex = -1;
    xIndex = -1;
    yIndex = -1;
    confIndex = -1;
    for i=1:size(attributes,1)
        if (strcmpi(attributes{i,1},'time')==1)
            timeIndex = i;
        elseif (strcmpi(attributes{i,1},'x')==1)
            xIndex = i;
        elseif (strcmpi(attributes{i,1},'y')==1)
            yIndex = i;
        elseif (strcmpi(attributes{i,1},'confidence')==1)
            confIndex = i;
        end
    end

    % assert all exist
    assert(timeIndex>0, '"time" attribute is not present in the .arff file')
    assert(xIndex>0, '"x" attribute is not present in the .arff file')
    assert(yIndex>0, '"y" attribute is not present in the .arff file')
    assert(confIndex>0, '"confidence" attribute is not present in the .arff file')

    % assign values to output data
    data = zeros(size(arffData,1),3);
    data(:,1) = arffData(:,timeIndex);
    data(:,2) = arffData(:,xIndex);
    data(:,3) = arffData(:,yIndex);

    pixelX = metadata.pixelX;
    pixelY = metadata.pixelY;
    width_m = metadata.dimensionX;
    height_m = metadata.dimensionY;
    distance_m = metadata.distance;

    conf = arffData(:,confIndex);

    % keep confidence for final standard
    % change confidence from ARFF to .coord convention
    %conf(conf(:)==0) = 1;
    %conf(conf(:)==4) = 0;
    % we shouldn't chek here for this
    %conf(data(:,2)<0 | data(:,2)>pixelX) = 0;
    %conf(data(:,3)<0 | data(:,3)>pixelY) = 0;
end    
